/*
 * ====================================================================
 * Copyright (c) 2002-2009 The RapidSvn Group.  All rights reserved.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program (in the file GPL.txt.  
 * If not, see <http://www.gnu.org/licenses/>.
 *
 * This software consists of voluntary contributions made by many
 * individuals.  For exact contribution history, see the revision
 * history and logs, available at http://rapidsvn.tigris.org/.
 * ====================================================================
 */


// app
#include "hist_entries.hpp"


const wxChar HISTORY_COMMIT_LOG[] = wxT("History/CommitLog");

const wxChar HISTORY_REPOSITORY[] = wxT("History/Repositories");

const wxChar HISTORY_WORKING_DIRECTORY[] = wxT("History/WorkingDirectories");

const wxChar HISTORY_COPYMOVE_DESTINATION[] = wxT("History/CopyMoveDestination");

const wxChar HISTORY_DIFF_URL[] = wxT("History/DiffUrl");

const wxChar HISTORY_EXISTING_WORKING_DIRECTORY[] = wxT("History/ExistingWorkingDirectory");

/* -----------------------------------------------------------------
 * local variables:
 * eval: (load-file "../rapidsvn-dev.el")
 * end:
 */
